@@ -1,6 +1,6 @@
 rerun <- function(object, ...) {
-  if (!is.element(class(object)[1], c("wls", "tssem1FEM", "tssem1REM", "meta", "meta3X", "reml", "tssem1FEM.cluster", "wls.cluster")))
-    stop("\"object\" must be an object of neither class \"meta\", \"meta3X\", \"wls\", \"reml\", \"tssem1FEM\", \"tssem1REM\", \"tssem1FEM.cluster\" or \"wls.cluster\".")
+  if (!is.element(class(object)[1], c("wls", "tssem1FEM", "tssem1REM", "meta", "meta3X", "reml", "tssem1FEM.cluster", "wls.cluster", "osmasem")))
+    stop("\"object\" must be an object of neither class \"meta\", \"meta3X\", \"wls\", \"reml\", \"tssem1FEM\", \"tssem1REM\", \"tssem1FEM.cluster\", \"wls.cluster\" or \"osmasem\".")
 
   if (is.element(class(object)[1], c("tssem1FEM.cluster", "wls.cluster"))) {
     out <- lapply(object, rerun, ...)
